@@ -4,7 +4,7 @@ import tempfile
 
 import pytest
 
-import vdb.lib.db as db
+from vdb.lib import db as db
 from vdb.lib.gha import GitHubSource
 from vdb.lib.nvd import NvdSource
 from vdb.lib.utils import parse_cpe
