@@ -1,4 +1,4 @@
-import vdb.lib.utils as utils
+from vdb.lib import utils as utils
 
 
 def test_normalise():
@@ -84,7 +84,16 @@ def test_version_len():
 def test_fix_test():
     assert (
         utils.fix_text(
-            "Unauthenticated crypto and weak IV in Magento\Framework\Encryption"
+            "Unauthenticated crypto and weak IV in Magento\\Framework\\Encryption"
         )
         == "Unauthenticated crypto and weak IV in Magento Framework Encryption"
     )
+
+
+def test_convert_md_references():
+    assert utils.convert_md_references(
+        "- [Issue #60](https://github.com/tj/node-growl/issues/60)\n- [PR #61](https://github.com/tj/node-growl/pull/61)"
+    ) == [
+        {"name": "Issue #60", "url": "https://github.com/tj/node-growl/issues/60"},
+        {"name": "PR #61", "url": "https://github.com/tj/node-growl/pull/61"},
+    ]
