@@ -7,9 +7,10 @@ import re
 
 from tabulate import tabulate
 
-import vdb.lib.config as config
-import vdb.lib.db as dbLib
+from vdb.lib import config as config
+from vdb.lib import db as dbLib
 from vdb.lib.gha import GitHubSource
+from vdb.lib.npm import NpmSource
 from vdb.lib.nvd import NvdSource
 
 logging.basicConfig(
@@ -50,11 +51,32 @@ def build_args():
         dest="sync",
         help="Sync to receive the latest vulnerability data. Should have invoked cache first.",
     )
+    parser.add_argument(
+        "--sync-npm",
+        action="store_true",
+        default=False,
+        dest="sync_npm",
+        help="Sync from npm.",
+    )
+    parser.add_argument(
+        "--sync-github",
+        action="store_true",
+        default=False,
+        dest="sync_github",
+        help="Sync from github.",
+    )
     parser.add_argument(
         "--search",
         dest="search",
         help="Search for package and version in the database. Use colon to separate package and version. Use comma to specify multiple values. Eg: android:8.0",
     )
+    parser.add_argument(
+        "--list",
+        action="store_true",
+        default=False,
+        dest="list",
+        help="List data in the db as a table",
+    )
     return parser.parse_args()
 
 
@@ -67,6 +89,7 @@ def print_results(results):
         "Id",
         "Package",
         "Affected Version",
+        "Fix Version",
         "CWE",
         "Severity",
         "Score",
@@ -88,6 +111,7 @@ def print_results(results):
                     id,
                     full_pkg,
                     package_issue.affected_location.version,
+                    package_issue.fixed_location,
                     vuln_occ_dict.get("problem_type"),
                     vuln_occ_dict.get("severity"),
                     vuln_occ_dict.get("cvss_score"),
@@ -110,6 +134,18 @@ def main():
         for s in [GitHubSource(), NvdSource()]:
             LOG.info("Syncing {}".format(s.__class__.__name__))
             s.download_recent()
+    if args.sync_npm:
+        for s in [NpmSource()]:
+            LOG.info("Syncing {}".format(s.__class__.__name__))
+            s.download_recent()
+    if args.sync_github:
+        for s in [GitHubSource()]:
+            LOG.info("Syncing {}".format(s.__class__.__name__))
+            s.download_recent()
+    if args.list:
+        db = dbLib.get()
+        results = dbLib.list_all_occurrence(db)
+        print_results(results)
     elif args.search:
         db = dbLib.get()
         search_list = re.split(r"[,|;]", args.search)
