@@ -16,12 +16,12 @@ CPE_REGEX = re.compile(
 class VulnerabilitySource(metaclass=ABCMeta):
     @classmethod
     @abstractmethod
-    def download_all():
+    def download_all(local_store=True):
         pass
 
     @classmethod
     @abstractmethod
-    def download_recent():
+    def download_recent(local_store=True):
         pass
 
     @classmethod
@@ -151,9 +151,7 @@ class VulnerabilityDetail(object):
         )
         self.severity = Severity.from_str(severity)
         self.description = description
-        self.fixed_location = VulnerabilityLocation.from_values(
-            fixed_location, self.min_affected_version, self.max_affected_version
-        )
+        self.fixed_location = fixed_location
         self.package_type = VulnerabilityDetail.get_type(cpe_uri, package_type)
         self.is_obsolete = is_obsolete
         self.source_update_time: datetime = convert_time(source_update_time)
@@ -203,9 +201,12 @@ class PackageIssue(object):
         self.affected_location = VulnerabilityLocation.from_values(
             affected_location, min_affected_version, max_affected_version
         )
-        self.fixed_location = VulnerabilityLocation.from_values(
-            fixed_location, None, None
-        )
+        # Extract the fixed version from fixed_location cpe uri
+        fixed_parts = CPE_REGEX.match(fixed_location) if fixed_location else None
+        if fixed_parts:
+            self.fixed_location = fixed_parts.group("version")
+        else:
+            self.fixed_location = ""
 
     @staticmethod
     def from_dict(package_issue):
@@ -217,7 +218,7 @@ class PackageIssue(object):
         return json.dumps(
             {
                 "affected_location": str(self.affected_location),
-                "fixed_location": str(self.fixed_location),
+                "fixed_location": self.fixed_location,
             }
         )
 
