@@ -1,6 +1,6 @@
-import vdb.lib.config as config
-import vdb.lib.storage as storage
-from vdb.lib.utils import version_compare, parse_cpe, convert_to_occurrence
+from vdb.lib import config as config
+from vdb.lib import storage as storage
+from vdb.lib.utils import convert_to_occurrence, parse_cpe, version_compare
 
 index_data = None
 vendor_index_data = None
@@ -63,6 +63,15 @@ def list_all(db):
     return storage.stream_read(db["db_file"])
 
 
+def list_all_occurrence(db):
+    """Method to return all data
+
+    :param db: db instance
+    :return: List of data stored as occurrences
+    """
+    return convert_to_occurrence(storage.stream_read(db["db_file"]))
+
+
 def index_count(index_file=config.vdb_bin_index):
     """
     Method to return the number of indexed items
