@@ -6,9 +6,9 @@ import tempfile
 import requests
 import ujson
 
-import vdb.lib.config as config
-import vdb.lib.db as dbLib
-from vdb.lib import CvssV3, Vulnerability, VulnerabilitySource, VulnerabilityDetail
+from vdb.lib import CvssV3, Vulnerability, VulnerabilityDetail, VulnerabilitySource
+from vdb.lib import config as config
+from vdb.lib import db as dbLib
 
 logging.basicConfig(
     level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
@@ -41,21 +41,23 @@ class NvdSource(VulnerabilitySource):
     """NVD CVE source. This uses CVE json 1.1 format that are split based on the year
     """
 
-    def download_all(self):
+    def download_all(self, local_store=True):
         """Download all historic cve data
         """
         data_list = []
         for y in range(now.year, int(start_year) - 1, -1):
             data = self.fetch(y)
-            self.store(data)
+            if local_store:
+                self.store(data)
             data_list += data
         return data_list
 
-    def download_recent(self):
+    def download_recent(self, local_store=True):
         """Method which downloads the recent CVE gzip from NVD
         """
         data = self.fetch("recent")
-        self.store(data)
+        if local_store:
+            self.store(data)
         return data
 
     def fetch(self, year):
@@ -175,6 +177,8 @@ class NvdSource(VulnerabilitySource):
                 for cc in node.get("children", []):
                     cpe_list += cc["cpe_match"]
             cpe_list += node.get("cpe_match", [])
+            cpe_details_list = []
+            fix_cpe_uri = None
             for cpe in cpe_list:
                 detail = {}
                 if cpe["vulnerable"]:
@@ -188,7 +192,14 @@ class NvdSource(VulnerabilitySource):
                     )
 
                     detail["source_update_time"] = vuln["lastModifiedDate"]
-                    details.append(VulnerabilityDetail.from_dict(detail))
+                    cpe_details_list.append(detail)
+                else:
+                    fix_cpe_uri = cpe["cpe23Uri"]
+            # Add fix version details
+            for det in cpe_details_list:
+                if fix_cpe_uri:
+                    det["fixed_location"] = fix_cpe_uri
+                details.append(VulnerabilityDetail.from_dict(det))
         if not details:
             return None
         return details
