@@ -2,8 +2,8 @@ import os.path
 
 import msgpack
 
-import vdb.lib.config as config
-from vdb.lib.utils import serialize_vuln_list, parse_cpe
+from vdb.lib import config as config
+from vdb.lib.utils import parse_cpe, serialize_vuln_list
 
 read_size = 256
 
