@@ -3,7 +3,7 @@ import re
 from datetime import datetime
 from enum import Enum
 
-from vdb.lib import Severity, CPE_REGEX, VulnerabilityOccurrence, PackageIssue
+from vdb.lib import CPE_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
 
 date_format_str = "%Y-%m-%dT%H:%M:%S"
 
@@ -415,7 +415,7 @@ def convert_to_occurrence(datas):
                 cvss_score=vobj["score"],
                 package_issue=PackageIssue(
                     affected_location=cpe_uri,
-                    fixed_location=None,
+                    fixed_location=vdetails.fixed_location,
                     min_affected_version=vdetails.min_affected_version,
                     max_affected_version=vdetails.max_affected_version,
                 ),
@@ -439,3 +439,20 @@ def fix_text(text):
         text = ""
     text = re.sub(r"[]^\\-]", " ", text)
     return text
+
+
+def convert_md_references(md_text):
+    """Method to convert markdown list to references url format"""
+    if not md_text:
+        return []
+    ref_list = []
+    md_text = md_text.replace("\n", "").strip()
+    for ref in md_text.split("- "):
+        if not ref:
+            continue
+        parts = ref.split("](")
+        if len(parts) == 2:
+            ref_list.append(
+                {"name": parts[0].replace("[", ""), "url": parts[1].replace(")", "")}
+            )
+    return ref_list
